.. image:: docs/_static/logo.png

|


Extending `Marzeion et al., (2012)`_, the model accounts for glacier geometry 
(including contributory branches) and includes an explicit ice dynamics module.
It can simulate past and future mass-balance, volume and geometry of (almost)
any glacier in the world in a fully automated workflow. We rely exclusively on
publicly available data for calibration and validation.

.. _Marzeion et al., (2012): http://www.the-cryosphere.net/6/1295/2012/tc-6-1295-2012.html


.. image:: docs/_static/ex_tasman.jpg


Installation, documentation
---------------------------

The documentation is hosted on ReadTheDocs: http://oggm.readthedocs.io


Get in touch
------------

- View the source code `on GitHub`_.
- Report bugs or share your ideas on the `issue tracker`_.
- Improve the model by submitting a `pull request`_.
- Or you can always send us an `e-mail`_ the good old way.

.. _e-mail: info@oggm.org
.. _on GitHub: https://github.com/OGGM/oggm
.. _issue tracker: https://github.com/OGGM/oggm/issues
.. _pull request: https://github.com/OGGM/oggm/pulls


About
-----

:Status:
    Experimental - in development

:Citation:
    .. image:: https://zenodo.org/badge/43965645.svg
        :target: https://zenodo.org/badge/latestdoi/43965645
        :alt: Zenodo

:Tests:
    .. image:: https://coveralls.io/repos/github/OGGM/oggm/badge.svg?branch=master
        :target: https://coveralls.io/github/OGGM/oggm?branch=master
        :alt: Code coverage

    .. image:: https://travis-ci.org/OGGM/oggm.svg?branch=master
        :target: https://travis-ci.org/OGGM/oggm
        :alt: Linux build status

    .. image:: https://ci.appveyor.com/api/projects/status/alealh9rxmqgd3nm/branch/master?svg=true
        :target: https://ci.appveyor.com/project/fmaussion/oggm
        :alt: Windows-conda build status

    .. image:: https://readthedocs.org/projects/oggm/badge/?version=latest
        :target: http://oggm.readthedocs.org/en/latest/?badge=latest
        :alt: Documentation status

:License:

    OGGM is available under the open source `GNU GPLv3 license`_.

    .. _GNU GPLv3 license: http://www.gnu.org/licenses/gpl-3.0.en.html

:Authors:

    See `whats-new`_ for a list of all contributors.

    .. _whats-new: http://oggm.readthedocs.org/en/latest/whats-new.html
